import { GetChannelsApiResponse, GetConnectionsApiResponse, MeApiResponse, PaginationAttributes, GetGroupApiResponse, GetGroupChannelsApiResponse, SearchApiResponse, GetBlockApiResponse, CreateBlockApiResponse, GetBlockChannelsApiResponse, CreateChannelApiResponse, GetChannelThumbApiResponse, GetChannelContentsApiResponse, ChannelConnectBlockApiResponse, ChannelConnectChannelApiResponse, GetUserChannelsApiResponse, GetUserApiResponse, GetUserFollowersApiResponse, GetUserFollowingApiResponse, GetBlockCommentApiResponse, CreateBlockCommentApiResponse } from './arena_api_types';
export declare class HttpError extends Error {
    readonly status: number;
    readonly name = "HttpError";
    constructor(message?: string, status?: number);
}
export interface ArenaBlockApi {
    get(): Promise<GetBlockApiResponse>;
    channels(options?: PaginationAttributes): Promise<GetBlockChannelsApiResponse>;
    update(data: {
        title?: string;
        description?: string;
        content?: string;
    }): Promise<undefined>;
    comments(options?: PaginationAttributes): Promise<GetBlockCommentApiResponse>;
    addComment(comment: string): Promise<CreateBlockCommentApiResponse>;
    deleteComment(commentId: number): Promise<undefined>;
    updateComment(commentId: number, comment: string): Promise<undefined>;
}
export interface ArenaUserApi {
    get(): Promise<GetUserApiResponse>;
    channels(options?: PaginationAttributes): Promise<GetUserChannelsApiResponse>;
    following(): Promise<GetUserFollowingApiResponse>;
    followers(): Promise<GetUserFollowersApiResponse>;
}
export declare type ChannelStatus = 'public' | 'closed' | 'private';
export interface ArenaGroupApi {
    get(): Promise<GetGroupApiResponse>;
    channels(options?: PaginationAttributes): Promise<GetGroupChannelsApiResponse>;
}
export interface ArenaChannelApi {
    create(status?: ChannelStatus): Promise<CreateChannelApiResponse>;
    get(options?: PaginationAttributes): Promise<GetChannelsApiResponse>;
    delete(): Promise<undefined>;
    update(data: {
        title: string;
        status?: ChannelStatus;
    }): Promise<undefined>;
    thumb(): Promise<GetChannelThumbApiResponse>;
    sort: {
        block(id: number, position: number): Promise<void>;
        channel(id: number, position: number): Promise<void>;
    };
    contents(options?: PaginationAttributes): Promise<GetChannelContentsApiResponse>;
    createBlock(data: {
        source?: string;
        content?: string;
        description?: string;
    }): Promise<CreateBlockApiResponse>;
    connect: {
        block(id: number): Promise<ChannelConnectBlockApiResponse>;
        channel(id: number): Promise<ChannelConnectChannelApiResponse>;
    };
    disconnect: {
        block(id: number): Promise<void>;
        connection(id: number): Promise<void>;
    };
    connections(options?: PaginationAttributes): Promise<GetConnectionsApiResponse[]>;
}
export interface ArenaSearchApi {
    everything(query: string, options?: PaginationAttributes): Promise<SearchApiResponse>;
    users(query: string, options?: PaginationAttributes): Promise<SearchApiResponse>;
    channels(query: string, options?: PaginationAttributes): Promise<SearchApiResponse>;
    blocks(query: string, options?: PaginationAttributes): Promise<SearchApiResponse>;
}
export interface ArenaApi {
    /**
     *  Fetch information about current authenticated user.
     */
    me(): Promise<MeApiResponse>;
    channels(options?: PaginationAttributes): Promise<GetChannelsApiResponse>;
    user(id: string): ArenaUserApi;
    group(slug: string): ArenaGroupApi;
    channel(slug: string): ArenaChannelApi;
    block(id: number): ArenaBlockApi;
    readonly search: ArenaSearchApi;
}
export declare type Fetch = (url: RequestInfo, init?: RequestInit) => Promise<Response>;
export declare type Date = {
    now(): number;
};
export declare class ArenaClient implements ArenaApi {
    private readonly domain;
    private readonly headers;
    private readonly fetch;
    private readonly date;
    private static defaultPaginationOptions;
    constructor(config?: {
        token?: string | null;
        fetch?: Fetch;
        date?: Date;
    });
    me(): Promise<any>;
    channels(options?: PaginationAttributes): Promise<GetChannelsApiResponse>;
    user(id: string): ArenaUserApi;
    group(slug: string): ArenaGroupApi;
    channel(slug: string): ArenaChannelApi;
    block(id: number): ArenaBlockApi;
    get search(): ArenaSearchApi;
    private createConnection;
    private sortConnection;
    private getJsonWithSearchAndPaginationQuery;
    private getJsonWithPaginationQuery;
    private getJson;
    private putJson;
    private postJson;
    private del;
    private paginationQueryString;
}
//# sourceMappingURL=arena_service.d.ts.map